import { IErrorHandler, INodeLocation, TransformerFeatures } from "@typescript-nameof/common";
import type ts = require("typescript");
import { IPluginConfig } from "./IPluginConfig.cjs";
import { ITypeScriptContext } from "./ITypeScriptContext.cjs";
/**
 * Provides features for transforming TypeScript code.
 */
export declare class TypeScriptFeatures extends TransformerFeatures<ts.Node, ITypeScriptContext> {
    /**
     * The configuration of the transformer.
     */
    private config?;
    /**
     * Initializes a new instance of the {@linkcode TransformerFeatures TypeScriptFeatures<T>} class.
     *
     * @param config
     * The configuration of the plugin.
     *
     * @param errorHandler
     * A component for reporting errors.
     */
    constructor(config?: IPluginConfig, errorHandler?: IErrorHandler<ts.Node, ITypeScriptContext>);
    /**
     * Gets an instance of a TypeScript compiler.
     */
    get TypeScript(): typeof ts;
    /**
     * Gets a fallback instance of typescript in case no `typescript` instance was found in the configuration.
     */
    protected get TypeScriptFallback(): typeof ts;
    /**
     * Gets the configuration of the transformer.
     */
    protected get Config(): IPluginConfig | undefined;
    /**
     * Reports the specified {@linkcode error}.
     *
     * @param location
     * The location of the specified {@linkcode node}.
     *
     * @param node
     * The node related to the error.
     *
     * @param context
     * The context of the operation.
     *
     * @param error
     * The error to process.
     */
    ReportError(location: INodeLocation, node: ts.Node, context: ITypeScriptContext, error: Error): void;
    /**
     * Initializes a new error handler.
     *
     * @returns
     * The newly created error handler.
     */
    protected InitializeErrorHandler(): IErrorHandler<ts.Node, ITypeScriptContext>;
    /**
     * Imports the module identified by the specified {@linkcode moduleSpecifier} using a {@linkcode require} call.
     *
     * @param moduleSpecifier
     * The specifier of the module to import.
     *
     * @returns
     * The content of the imported module.
     */
    private Require;
}
